@@ -1,5 +1,5 @@
 package Appium::Commands;
-$Appium::Commands::VERSION = '0.02';
+$Appium::Commands::VERSION = '0.03';
 # ABSTRACT: Appium specific extensions to the Webdriver JSON protocol
 use Moo;
 extends 'Selenium::Remote::Commands';
@@ -37,121 +37,121 @@ has 'get_cmds' => (
             #         url => 'session/:sessionId/touch/multi/perform',
             #         no_content_success => 1
             #     },
-            #     get_app_strings => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/app/strings',
-            #         no_content_success => 1
-            #     },
-            #     press_keycode => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/press_keycode',
-            #         no_content_success => 1
-            #     },
-            #     long_press_keycode => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/long_press_keycode',
-            #         no_content_success => 1
-            #     },
-            #     get_current_activity => {
-            #         method => 'GET',
-            #         url => 'session/:sessionId/appium/device/current_activity',
-            #         no_content_success => 0
-            #     },
-            #     set_immediate_value => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/element/$elementId/value',
-            #         no_content_success => 1
-            #     },
-            #     pull_file => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/pull_file',
-            #         no_content_success => 1
-            #     },
-            #     pull_folder => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/pull_folder',
-            #         no_content_success => 1
-            #     },
-            #     push_file => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/push_file',
-            #         no_content_success => 1
-            #     },
-            #     complex_find => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/app/complex_find',
-            #         no_content_success => 1
-            #     },
-            #     background => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/app/background',
-            #         no_content_success => 1
-            #     },
-            #     is_app_installed => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/app_installed',
-            #         no_content_success => 1
-            #     },
-            #     install_app => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/install_app',
-            #         no_content_success => 1
-            #     },
-            #     remove_app => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/remove_app',
-            #         no_content_success => 1
-            #     },
-            #     launch_app => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/app/launch',
-            #         no_content_success => 1
-            #     },
-            #     close_app => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/app/close',
-            #         no_content_success => 1
-            #     },
-            #     end_test_coverage => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/app/end_test_coverage',
-            #         no_content_success => 1
-            #     },
-            #     lock => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/lock',
-            #         no_content_success => 1
-            #     },
-            #     shake => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/shake',
-            #         no_content_success => 1
-            #     },
-            #     reset => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/app/reset',
-            #         no_content_success => 1
-            #     },
+            app_strings => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/app/strings',
+                no_content_success => 1
+            },
+            press_keycode => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/press_keycode',
+                no_content_success => 1
+            },
+            long_press_keycode => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/long_press_keycode',
+                no_content_success => 1
+            },
+            current_activity => {
+                method => 'GET',
+                url => 'session/:sessionId/appium/device/current_activity',
+                no_content_success => 0
+            },
+            set_value => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/element/$elementId/value',
+                no_content_success => 1
+            },
+            pull_file => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/pull_file',
+                no_content_success => 0
+            },
+            pull_folder => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/pull_folder',
+                no_content_success => 0
+            },
+            push_file => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/push_file',
+                no_content_success => 1
+            },
+            complex_find => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/app/complex_find',
+                no_content_success => 1
+            },
+            background_app => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/app/background',
+                no_content_success => 1
+            },
+            is_app_installed => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/app_installed',
+                no_content_success => 1
+            },
+            install_app => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/install_app',
+                no_content_success => 1
+            },
+            remove_app => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/remove_app',
+                no_content_success => 1
+            },
+            launch_app => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/app/launch',
+                no_content_success => 1
+            },
+            close_app => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/app/close',
+                no_content_success => 1
+            },
+            end_test_coverage => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/app/end_test_coverage',
+                no_content_success => 1
+            },
+            lock => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/lock',
+                no_content_success => 1
+            },
+            shake => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/shake',
+                no_content_success => 1
+            },
+            reset => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/app/reset',
+                no_content_success => 1
+            },
             hide_keyboard => {
                 method => 'POST',
                 url => 'session/:sessionId/appium/device/hide_keyboard',
                 no_content_success => 1
             },
-            #     open_notifications => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/appium/device/open_notifications',
-            #         no_content_success => 1
-            #     },
-            #     get_network_connection => {
-            #         method => 'GET',
-            #         url => 'session/:sessionId/network_connection',
-            #         no_content_success => 0
-            #     },
-            #     set_network_connection => {
-            #         method => 'POST',
-            #         url => 'session/:sessionId/network_connection',
-            #         no_content_success => 1
-            #     },
+            open_notifications => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/device/open_notifications',
+                no_content_success => 1
+            },
+            network_connection => {
+                method => 'GET',
+                url => 'session/:sessionId/network_connection',
+                no_content_success => 0
+            },
+            set_network_connection => {
+                method => 'POST',
+                url => 'session/:sessionId/network_connection',
+                no_content_success => 1
+            },
             #     get_available_ime_engines => {
             #         method => 'GET',
             #         url => 'session/:sessionId/ime/available_engines',
@@ -177,6 +177,11 @@ has 'get_cmds' => (
             #         url => 'session/:sessionId/ime/active_engine',
             #         no_content_success => 0
             #     }
+            set_text => {
+                method => 'POST',
+                url => 'session/:sessionId/appium/element/:element/replace_value',
+                no_content_success => 1
+            }
         };
 
         foreach (keys %$appium_commands) {
@@ -202,7 +207,7 @@ Appium::Commands - Appium specific extensions to the Webdriver JSON protocol
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
@@ -229,7 +234,7 @@ L<Selenium::Remote::Commands|Selenium::Remote::Commands>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/gempesaw/Appium-Perl-Client/issues
+https://github.com/appium/perl-client/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
